@@ -4,18 +4,12 @@ from . import cookieGetter
 
 
 
-
-
-
 def getFinraStockID(ticker):
 
   cookies = cookieGetter.get() 
 
   s = requests.Session()
-  for cookie in cookies:
-    s.cookies.set(cookie['name'], cookie['value'])
-  
-  print(s.cookies)
+  s.cookies = cookies
 
   url = f"http://finra-markets.morningstar.com/acb.jsp?&condition=ST,FE,FC,FO,2,1,7&acbinstid=FINRA&kw={ticker}"
   response = s.get( url )
